@@ -5,7 +5,7 @@ function(num,y,A,mu0,Sigma0,Phi,Ups,Gam,cQ,cR,input){
 #       cQ=chol(Q), cR=chol(R)
 #  Use Ups=0 or Gam=0 or input=0 if these aren't needed
 #
- kf=Kfilter1(num,y,A,mu0,Sigma0,Phi,Ups,Gam,cQ,cR,input)
+ kf=astsa::Kfilter1(num,y,A,mu0,Sigma0,Phi,Ups,Gam,cQ,cR,input)
  pdim=nrow(as.matrix(Phi))  
  xs=array(NA, dim=c(pdim,1,num))      # xs=x_t^n
  Ps=array(NA, dim=c(pdim,pdim,num))   # Ps=P_t^n
